@@ -37,8 +37,6 @@ pysvn_module::pysvn_module()
     pysvn_client::init_type();
     pysvn_transaction::init_type();
     pysvn_revision::init_type();
-    pysvn_status::init_type();
-    pysvn_entry::init_type();
 
     pysvn_enum< svn_opt_revision_kind >::init_type();
     pysvn_enum_value< svn_opt_revision_kind >::init_type();
@@ -61,9 +59,19 @@ pysvn_module::pysvn_module()
     pysvn_enum< svn_node_kind_t >::init_type();
     pysvn_enum_value< svn_node_kind_t >::init_type();
 
-    add_keyword_method("Client", &pysvn_module::new_client, pysvn_client_doc);
+#if defined( PYSVN_HAS_DIFF_FILE_IGNORE_SPACE )
+    pysvn_enum< svn_diff_file_ignore_space_t >::init_type();
+    pysvn_enum_value< svn_diff_file_ignore_space_t >::init_type();
+#endif
+
+#if defined( PYSVN_HAS_CLIENT_DIFF_SUMMARIZE )
+    pysvn_enum< svn_client_diff_summarize_kind_t >::init_type();
+    pysvn_enum_value< svn_client_diff_summarize_kind_t >::init_type();
+#endif
+
+    add_keyword_method("_Client", &pysvn_module::new_client, pysvn_client_doc);
     add_keyword_method("Revision", &pysvn_module::new_revision, pysvn_revision_doc);
-    add_keyword_method("Transaction", &pysvn_module::new_transaction, pysvn_transaction_doc);
+    add_keyword_method("_Transaction", &pysvn_module::new_transaction, pysvn_transaction_doc);
 
     initialize( pysvn_module_doc );
 
@@ -107,6 +115,9 @@ pysvn_module::pysvn_module()
     d["wc_merge_outcome"] = Py::asObject( new pysvn_enum< svn_wc_merge_outcome_t >() );
     d["wc_notify_state"] = Py::asObject( new pysvn_enum< svn_wc_notify_state_t >() );
     d["node_kind"] = Py::asObject( new pysvn_enum< svn_node_kind_t >() );
+#if defined( PYSVN_HAS_CLIENT_DIFF_SUMMARIZE )
+    d["diff_summarize_kind"] = Py::asObject( new pysvn_enum< svn_client_diff_summarize_kind_t >() );
+#endif
 }
 
 pysvn_module::~pysvn_module()
@@ -114,12 +125,14 @@ pysvn_module::~pysvn_module()
 }
 
 static const char name_config_dir[] = "config_dir";
+static const char name_result_wrappers[] = "result_wrappers";
 
 Py::Object pysvn_module::new_client( const Py::Tuple &a_args, const Py::Dict &a_kws )
 {
     static argument_description args_desc[] =
     {
     { false, name_config_dir },
+    { false, name_result_wrappers },
     { false, NULL }
     };
 
@@ -128,7 +141,11 @@ Py::Object pysvn_module::new_client( const Py::Tuple &a_args, const Py::Dict &a_
 
     std::string config_dir = args.getUtf8String( name_config_dir, "" );
 
-    return Py::asObject( new pysvn_client( *this, config_dir ) );
+    Py::Dict result_wrappers_dict;
+    if( args.hasArg( name_result_wrappers ) )
+        result_wrappers_dict = args.getArg( name_result_wrappers );
+
+    return Py::asObject( new pysvn_client( *this, config_dir, result_wrappers_dict ) );
 }
 
 static const char name_repos_path[] = "repos_path";
@@ -141,6 +158,7 @@ Py::Object pysvn_module::new_transaction( const Py::Tuple &a_args, const Py::Dic
     {
     { true, name_repos_path },
     { true, name_transaction_name },
+    { false, name_result_wrappers },
     { false, NULL }
     };
 
@@ -150,7 +168,11 @@ Py::Object pysvn_module::new_transaction( const Py::Tuple &a_args, const Py::Dic
     std::string repos_path = args.getUtf8String( name_repos_path );
     std::string transaction_name = args.getUtf8String( name_transaction_name );
 
-    pysvn_transaction *t = new pysvn_transaction( *this );
+    Py::Dict result_wrappers_dict;
+    if( args.hasArg( name_result_wrappers ) )
+        result_wrappers_dict = args.getArg( name_result_wrappers );
+
+    pysvn_transaction *t = new pysvn_transaction( *this, result_wrappers_dict );
     Py::Object result( Py::asObject( t ) );
     t->init( repos_path, transaction_name );
     return result;
@@ -185,50 +207,50 @@ Py::Object pysvn_module::new_revision( const Py::Tuple &a_args, const Py::Dict &
     pysvn_revision *rev = NULL;
     switch( kind )
     {
-    case svn_opt_revision_date:
-    {
-        static argument_description args_desc[] =
+        case svn_opt_revision_date:
         {
-        { true, name_kind },
-        { true, name_date },
-        { false, NULL }
-        };
-        FunctionArguments args( "Revision", args_desc, a_args, a_kws );
-        args.check();
-        Py::Float date( args.getArg( name_date ) );
+            static argument_description args_desc[] =
+            {
+            { true, name_kind },
+            { true, name_date },
+            { false, NULL }
+            };
+            FunctionArguments args( "Revision", args_desc, a_args, a_kws );
+            args.check();
+            Py::Float date( args.getArg( name_date ) );
 
-        rev = new pysvn_revision( kind, double(date) );
-        break;
-    }
+            rev = new pysvn_revision( kind, double(date) );
+            break;
+        }
 
-    case svn_opt_revision_number:
-    {
-        static argument_description args_desc[] =
+        case svn_opt_revision_number:
         {
-        { true, name_kind },
-        { true, name_number },
-        { false, NULL }
-        };
-        FunctionArguments args( "Revision", args_desc, a_args, a_kws );
-        args.check();
-        Py::Int revnum( args.getArg( name_number ) );
+            static argument_description args_desc[] =
+            {
+            { true, name_kind },
+            { true, name_number },
+            { false, NULL }
+            };
+            FunctionArguments args( "Revision", args_desc, a_args, a_kws );
+            args.check();
+            Py::Int revnum( args.getArg( name_number ) );
 
-        rev = new pysvn_revision( kind, 0, long( revnum ) );
-        break;
-    }
+            rev = new pysvn_revision( kind, 0, long( revnum ) );
+            break;
+        }
 
-    default:
-    {
-        static argument_description args_desc[] =
+        default:
         {
-        { true, name_kind },
-        { false, NULL }
-        };
-        FunctionArguments args( "Revision", args_desc, a_args, a_kws );
-        args.check();
+            static argument_description args_desc[] =
+            {
+            { true, name_kind },
+            { false, NULL }
+            };
+            FunctionArguments args( "Revision", args_desc, a_args, a_kws );
+            args.check();
 
-        rev = new pysvn_revision( kind );
-    }
+            rev = new pysvn_revision( kind );
+        }
     }
 
     return Py::asObject( rev );
