@@ -52,8 +52,10 @@ def help( argv ):
 
     where <options> is one or more of:
         --verbose
+        --enable-debug
         --pycxx-dir=<dir>
         --apr-inc-dir=<dir>
+        --svn-root-dir=<dir>
         --svn-inc-dir=<dir>
         --svn-lib-dir=<dir>
         --define=<define-string>
@@ -99,12 +101,15 @@ class MakeFileCreater:
 
     def createMakefile( self, argv ):
         self.verbose = '--verbose' in argv
-
         self.detectMacVersion()
 
         if self.verbose:
             print 'Info: Creating makefile for python %r' % (sys.version_info,)
 
+        debug_cflags_list = []
+        if '--enable-debug' in argv:
+            debug_cflags_list.append( '-g' )
+
         include_dir_list = []
 
         # add python include dirs
@@ -146,6 +151,9 @@ class MakeFileCreater:
             'svn_include':      svn_include,
             'includes':         ' '.join( ['-I%s' % include_dir for include_dir in include_dir_list] ),
 
+            # debug_cflags
+            'debug_cflags':     ' '.join( debug_cflags_list ),
+            
             # py_cflags
             'py_cflags':        ' '.join( py_cflags_list ),
 
@@ -167,7 +175,9 @@ class MakeFileCreater:
         if self.is_mac_os_x:
             # need to figure out the framework dir to use otherwise the latest
             # python framework will be used and not the one matching this python
-            framework_dir = distutils.sysconfig.get_python_inc().split('/Python.framework')[0]
+            var_prefix = distutils.sysconfig.get_config_var('prefix')
+            var_ldlibrary = distutils.sysconfig.get_config_var('LDLIBRARY')
+            framework_lib = os.path.join( var_prefix, os.path.basename( var_ldlibrary ) )
 
             if self.cmp_mac_os_x_version( (10,4) ) >= 0:
                 if self.verbose:
@@ -175,13 +185,13 @@ class MakeFileCreater:
 
                 # 10.4 needs the libintl.a but 10.3 does not
                 template_values['extra_libs'] = '%(svn_lib_dir)s/libintl.a' % template_values
-                template_values['frameworks'] = '-F%s -framework System -framework Python -framework CoreFoundation -framework Kerberos' % framework_dir
+                template_values['frameworks'] = '-framework System %s -framework CoreFoundation -framework Kerberos' % framework_lib
             else:
                 if self.verbose:
                     print 'Info: Using Mac OS X 10.3 makefile template'
 
                 template_values['extra_libs'] = ''
-                template_values['frameworks'] = '-F%s -framework System -framework Python -framework CoreFoundation' % framework_dir
+                template_values['frameworks'] = '-framework System %s -framework CoreFoundation' % framework_lib
 
             if self.is_mac_os_x_fink:
                 makefile.write( self.makefile_template_macosx_fink % template_values )
@@ -191,55 +201,121 @@ class MakeFileCreater:
 
             else:
                 makefile.write( self.makefile_template_macosx % template_values )
+        elif sys.platform.startswith('aix'):
+            if self.verbose:
+                print 'Info: Using AIX makefile template'
+            for path in sys.path:
+                python_exp = os.path.join(path, 'config', 'python.exp')
+                if os.path.exists(python_exp):
+                    template_values['python_exp'] = python_exp
+                    break
+            else:
+                python_exp = os.path.abspath(os.path.join(sys.executable, os.path.pardir, os.path.pardir, 
+                                                          'lib', 'python2.4', 'config', 'python.exp'))
+                if os.path.exists(python_exp):
+                    template_values['python_exp'] = python_exp
+                else:
+                    template_values['python_exp'] = 'python.exp'
+            makefile.write( self.makefile_template_aix % template_values )
         else:
             if self.verbose:
                 print 'Info: Using unix makefile template'
             makefile.write( self.makefile_template % template_values )
+
+        f = file( 'pysvn_common.mak', 'r' )
+        makefile.write( f.read() )
+        f.close()
         makefile.close()
 
         print 'Info: Creating Makefile for Tests'
 
         makefile = file( '../Tests/Makefile', 'w' )
         makefile.write( self.makefile_tests_template % template_values )
+        f = file( '../Tests/pysvn_test_common.mak', 'r' )
+        makefile.write( f.read() )
+        f.close()
         makefile.close()
 
 
     makefile_tests_template = '''#
 #	Created by pysvn Extension/Source/setup.py
+#       -- makefile_tests_template --
 #
 PYTHON=%(python_exe)s
-include pysvn_test_common.mak
+
+#include pysvn_test_common.mak
 '''
 
     makefile_template = '''#
 #	Created by pysvn Extension/Source/setup.py
+#       -- makefile_template --
 #
 PYTHON=%(python_exe)s
 SVN_INCLUDE=%(svn_include)s
 CCC=g++ -c
-CCCFLAGS=-Wall -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s
+CCCFLAGS=-Wall -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cflags)s
 CC=gcc -c
-CCFLAGS=-Wall -fPIC %(includes)s
+CCFLAGS=-Wall -fPIC %(includes)s %(debug_cflags)s
 PYCXX=%(pycxx_dir)s
-LDSHARED=g++ -shared
-LDLIBS=-L%(svn_lib_dir)s \
+LDSHARED=g++ -shared %(debug_cflags)s
+LDLIBS=-L%(svn_lib_dir)s -Wl,--rpath -Wl,%(svn_lib_dir)s \
 -lsvn_client-1 \
--lsvn_repos-1
+-lsvn_diff-1 \
+-lsvn_repos-1 `apr-config --link-ld --libs`
 
-include pysvn_common.mak
+#include pysvn_common.mak
+'''
+
+    makefile_template_aix = '''#
+#	Created by pysvn Extension/Source/setup.py
+#       -- makefile_template_aix --
+#
+PYTHON=%(python_exe)s
+SVN_INCLUDE=%(svn_include)s
+CCC=g++ -c
+CCCFLAGS=-Wall -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cflags)s
+CC=gcc -c
+CCFLAGS=-Wall -fPIC %(includes)s %(debug_cflags)s
+PYCXX=%(pycxx_dir)s
+LDSHARED=g++ -shared %(debug_cflags)s
+LDLIBS=-L%(svn_lib_dir)s \
+-lsvn_client-1   \
+-lsvn_repos-1    \
+-lsvn_subr-1     \
+-lsvn_delta-1    \
+-lsvn_fs_fs-1    \
+-lsvn_fs-1       \
+-lsvn_ra_svn-1   \
+-lsvn_repos-1    \
+-lsvn_ra_local-1 \
+-lsvn_ra_dav-1   \
+-lsvn_diff-1     \
+-lsvn_ra-1       \
+-lsvn_wc-1       \
+-lapr-0          \
+-lneon           \
+-laprutil-0      \
+-liconv          \
+-lexpat          \
+-lintl           \
+-lpthread        \
+-Wl,-bI:%(python_exp)s
+
+#include pysvn_common.mak
 '''
 
     makefile_template_macosx = '''#
 #	Created by pysvn Extension/Source/setup.py
+#       -- makefile_template_macosx --
 #
 PYTHON=%(python_exe)s
 SVN_INCLUDE=%(svn_include)s
 CCC=g++ -c
-CCCFLAGS=-Wall -Wno-long-double -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s
+CCCFLAGS=-Wall -Wno-long-double -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cflags)s
 CC=gcc -c
-CCFLAGS=-Wall -Wno-long-double -fPIC %(includes)s
+CCFLAGS=-Wall -Wno-long-double -fPIC %(includes)s %(debug_cflags)s
 PYCXX=%(pycxx_dir)s
-LDSHARED=g++ -bundle -g -u _PyMac_Error %(frameworks)s
+LDSHARED=g++ -bundle %(debug_cflags)s -u _PyMac_Error %(frameworks)s
 LDLIBS=-L%(svn_lib_dir)s \
 -L%(apr_lib_dir)s \
 -lsvn_client-1 \
@@ -247,21 +323,23 @@ LDLIBS=-L%(svn_lib_dir)s \
 -lsvn_wc-1 \
 -lsvn_fs-1 \
 -lsvn_subr-1 \
+-lsvn_diff-1 \
 -l%(lib_apr)s
-include pysvn_common.mak
+#include pysvn_common.mak
 '''
 
     makefile_template_macosx_fink = '''#
 #	Created by pysvn Extension/Source/setup.py
+#       -- makefile_template_macosx_fink --
 #
 PYTHON=%(python_exe)s
 SVN_INCLUDE=%(svn_include)s
 CCC=g++ -c
-CCCFLAGS=-Wall -Wno-long-double -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s
+CCCFLAGS=-Wall -Wno-long-double -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cflags)s
 CC=gcc -c
-CCFLAGS=-Wall -Wno-long-double -fPIC %(includes)s
+CCFLAGS=-Wall -Wno-long-double -fPIC %(includes)s %(debug_cflags)s
 PYCXX=%(pycxx_dir)s
-LDSHARED=g++ -bundle -g -u _PyMac_Error %(frameworks)s
+LDSHARED=g++ -bundle %(debug_cflags)s -u _PyMac_Error %(frameworks)s
 LDLIBS= \
 %(svn_lib_dir)s/libsvn_client-1.a \
 %(svn_lib_dir)s/libsvn_subr-1.a \
@@ -285,20 +363,22 @@ LDLIBS= \
 %(svn_lib_dir)s/libxml2.a \
 %(svn_lib_dir)s/libdb-4.3.a \
  -lintl.3 -liconv.2 -lz
-include pysvn_common.mak
+
+#include pysvn_common.mak
 '''
 
     makefile_template_macosx_darwin_ports = '''#
 #	Created by pysvn Extension/Source/setup.py
+#       -- makefile_template_macosx_darwin_ports --
 #
 PYTHON=%(python_exe)s
 SVN_INCLUDE=%(svn_include)s
 CCC=g++ -c
-CCCFLAGS=-Wall -Wno-long-double -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s
+CCCFLAGS=-Wall -Wno-long-double -fPIC -fexceptions -frtti %(includes)s %(py_cflags)s %(debug_cflags)s
 CC=gcc -c
-CCFLAGS=-Wall -Wno-long-double -fPIC %(includes)s
+CCFLAGS=-Wall -Wno-long-double -fPIC %(includes)s %(debug_cflags)s
 PYCXX=%(pycxx_dir)s
-LDSHARED=g++ -bundle -g -u _PyMac_Error %(frameworks)s
+LDSHARED=g++ -bundle %(debug_cflags)s -u _PyMac_Error %(frameworks)s
 LDLIBS= \
 %(svn_lib_dir)s/libsvn_client-1.a \
 %(svn_lib_dir)s/libsvn_subr-1.a \
@@ -324,20 +404,24 @@ LDLIBS= \
 -L%(apr_lib_dir)s \
 -l%(lib_apr)s \
 -lz
-include pysvn_common.mak
+
+#include pysvn_common.mak
 '''
 
     def find_pycxx( self, argv ):
+        return '/usr/share/python%s/CXX' % sys.version[:3]
         return self.find_dir( argv,
                     'PyCXX include',
                     '--pycxx-dir=',
-                    [   '../Import/pycxx_5_3_5'],
-                    'CXX/Version.hxx' )
+                    None,
+                    [   '../Import/pycxx-5.3.6'],
+                    'cxxsupport.cxx' )
 
     def find_svn_inc( self, argv ):
         return self.find_dir( argv,
                     'SVN include',
                     '--svn-inc-dir=',
+                    'include/subversion-1',
                     [
                         '/opt/local/include/subversion-1',      # Darwin - darwin ports
                         '/sw/include/subversion-1',             # Darwin - Fink
@@ -351,6 +435,7 @@ include pysvn_common.mak
         dir = self.find_dir( argv,
                     'SVN library',
                     '--svn-lib-dir=',
+                    'lib',
                     [
                         '/opt/local/lib',                       # Darwin - darwin ports
                         '/sw/lib',                              # Darwin - Fink
@@ -368,11 +453,12 @@ include pysvn_common.mak
 
     def find_apr_inc( self, argv ):
         last_exception = None
-        for apr_ver in ['apr-1', 'apr-0']:
+        for apr_ver in ['apr-1.0', 'apr-1', 'apr-0']:
             try:
                 return self.find_dir( argv,
                     'APR include',
                     '--apr-inc-dir=',
+                    None,
                     [
                         '/opt/local/include/%s' % apr_ver,      # Darwin - darwin ports
                         '/sw/include/%s' % apr_ver,             # Darwin - fink
@@ -398,6 +484,7 @@ include pysvn_common.mak
                 return self.find_dir( argv,
                     'APR library',
                     '--apr-lib-dir=',
+                    None,
                     [
                         '/opt/local/lib',                       # Darwin - darwin ports
                         '/sw/lib',                              # Darwin - fink
@@ -414,17 +501,22 @@ include pysvn_common.mak
         raise last_exception
 
 
-    def find_dir( self, argv, name, kw, base_dir_list, check_file=None ):
-        dir = self.__find_dir( argv, name, kw, base_dir_list, check_file )
-        print 'Info: Found %14.14s in %s' % (name, dir)
-        return dir
+    def find_dir( self, argv, name, kw, svn_root_suffix, base_dir_list, check_file ):
+        dirname = self.__find_dir( argv, name, kw, svn_root_suffix, base_dir_list, check_file )
+        print 'Info: Found %14.14s in %s' % (name, dirname)
+        return dirname
 
-    def __find_dir( self, argv, name, kw, base_dir_list, check_file=None ):
+    def __find_dir( self, argv, name, kw, svn_root_suffix, base_dir_list, check_file ):
+        # override the base_dir_list from the command line kw
+        svn_root_dir = None
         for arg in argv[2:]:
             if arg[0:len(kw)] == kw:
-                return arg[len(kw):]
+                base_dir_list = [arg[len(kw):]]
+            elif( arg[0:len('--svn-root-dir=')] == '--svn-root-dir='
+            and svn_root_suffix is not None ):
+                base_dir_list = ['%s/%s' % (arg[len('--svn-root-dir='):], svn_root_suffix)]
 
-        # expect to find the pycxx in this source tree
+        # expect to find check_file in one of the dir
         for dir in base_dir_list:
             full_check_file = os.path.join( dir, check_file )
             if self.verbose:
@@ -432,7 +524,7 @@ include pysvn_common.mak
             if os.path.exists( full_check_file ):
                 return os.path.abspath( dir )
 
-        raise SetupError, 'cannot find %s - use %s' % (name, kw)
+        raise SetupError, 'cannot find %s %s - use %s' % (name, check_file, kw)
 
 if __name__ == '__main__':
     sys.exit( main( sys.argv ) )
